// ************************************************************************** //
//
//  BornAgain: simulate and fit scattering at grazing incidence
//
//! @file      Core/SoftParticle/FormFactorGauss.h
//! @brief     Declares class FormFactorGauss.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2015
//! @authors   Scientific Computing Group at MLZ Garching
//! @authors   C. Durniak, M. Ganeva, G. Pospelov, W. Van Herck, J. Wuttke
//
// ************************************************************************** //

#ifndef FORMFACTORGAUSS_H
#define FORMFACTORGAUSS_H

#include "IFormFactorBorn.h" // inheriting from

//! @class FormFactorGauss
//! @ingroup formfactors
//! @brief The formfactor of a gaussian.

class BA_CORE_API_ FormFactorGauss : public IFormFactorBorn
{
public:
    FormFactorGauss(double volume);
    FormFactorGauss(double width, double height);

    FormFactorGauss* clone() const { return new FormFactorGauss(m_width, m_height); }
    void accept(ISampleVisitor* visitor) const final { visitor->visit(this); }

    double getWidth() const { return m_width; }
    double getHeight() const { return m_height; }

    //! Returns width
    double getRadialExtension() const final { return m_width; }

    complex_t evaluate_for_q(const cvector_t q) const final;

private:
    double m_width;
    double m_height;
    double m_max_ql;
    void initialize();
};

#endif // FORMFACTORGAUSS_H
